@@ -5,15 +5,13 @@ use warnings;
 use Carp;
 
 use AnyEvent;
+use Coro;
 use Coro::AnyEvent qw(sleep);
 use Coro::Channel;
 use Coro::ProcessPool::Process;
-use Coro::Storable qw(freeze thaw);
-use Coro;
-use MIME::Base64 qw(encode_base64 decode_base64);
 use Sys::Info;
 
-our $VERSION = '0.12_01';
+our $VERSION = '0.12_02';
 
 if ($^O eq 'MSWin32') {
     die 'MSWin32 is not supported';
